==> haskell-aeson-better-errors-0.9.1.1-102-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-better-errors
version:              0.9.1.1
visibility:           public
id:                   aeson-better-errors-0.9.1.1-4Tq7MlAjlBHr6DOm45MgS
key:                  aeson-better-errors-0.9.1.1-4Tq7MlAjlBHr6DOm45MgS
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  3df2011cd3cc9d93c1b9350253ecb8ea
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.2.8/site-local/aeson-better-errors-0.9.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aeson-better-errors-0.9.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.1-4Tq7MlAjlBHr6DOm45MgS
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0
    bytestring-0.11.4.0 dlist-1.0-HCxoMn9TirQDgPCFxho7O mtl-2.2.2
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc text-1.2.5.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.1-111-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-better-errors
version:              0.9.1.1
visibility:           public
id:                   aeson-better-errors-0.9.1.1-6hxnlkstVXlYEP1e9sVb0
key:                  aeson-better-errors-0.9.1.1-6hxnlkstVXlYEP1e9sVb0
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  265f30c1897dc01eda83c0746b9690de
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.2.8/site-local/aeson-better-errors-0.9.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aeson-better-errors-0.9.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.1-6hxnlkstVXlYEP1e9sVb0
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 dlist-1.0-LNr75TD4CZoKEEzkBmhWjA mtl-2.2.2
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD text-1.2.5.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
